package betterquesting.api.utils;

import betterquesting.api.api.QuestingAPI;
import betterquesting.api.placeholders.ItemPlaceholder;
import betterquesting.api.placeholders.PlaceholderConverter;
import betterquesting.api2.utils.BQThreadedIO;
import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import com.google.gson.JsonArray;
import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.lang.reflect.Field;
import java.nio.charset.StandardCharsets;
import java.nio.file.Files;
import java.nio.file.StandardCopyOption;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.concurrent.Future;
import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import net.minecraft.entity.Entity;
import net.minecraft.entity.EntityList;
import net.minecraft.item.Item;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.util.ChatAllowedCharacters;
import net.minecraft.world.World;
import net.minecraftforge.fluids.Fluid;
import net.minecraftforge.fluids.FluidRegistry;
import net.minecraftforge.fluids.FluidStack;
import org.apache.logging.log4j.Level;

/* loaded from: betterquesting_api_utils.jar:betterquesting/api/utils/JsonHelper.class */
public class JsonHelper {
    private static Gson GSON = new GsonBuilder().setPrettyPrinting().create();

    public static JsonArray GetArray(JsonObject json, String id) {
        if (json == null) {
            return new JsonArray();
        }
        if (json.has(id) && json.get(id).isJsonArray()) {
            return json.get(id).getAsJsonArray();
        }
        return new JsonArray();
    }

    public static JsonObject GetObject(JsonObject json, String id) {
        if (json == null) {
            return new JsonObject();
        }
        if (json.has(id) && json.get(id).isJsonObject()) {
            return json.get(id).getAsJsonObject();
        }
        return new JsonObject();
    }

    public static String GetString(JsonObject json, String id, String def) {
        if (json == null) {
            return def;
        }
        if (json.has(id) && json.get(id).isJsonPrimitive() && json.get(id).getAsJsonPrimitive().isString()) {
            return json.get(id).getAsString();
        }
        return def;
    }

    public static Number GetNumber(JsonObject json, String id, Number def) {
        if (json == null) {
            return def;
        }
        if (json.has(id) && json.get(id).isJsonPrimitive()) {
            try {
                return json.get(id).getAsNumber();
            } catch (Exception e) {
                return def;
            }
        }
        return def;
    }

    public static boolean GetBoolean(JsonObject json, String id, boolean def) {
        if (json == null) {
            return def;
        }
        if (json.has(id) && json.get(id).isJsonPrimitive()) {
            try {
                return json.get(id).getAsBoolean();
            } catch (Exception e) {
                return def;
            }
        }
        return def;
    }

    public static ArrayList<JsonElement> GetUnderlyingArray(JsonArray array) {
        try {
            Field field = JsonArray.class.getDeclaredField("elements");
            field.setAccessible(true);
            return (ArrayList) field.get(array);
        } catch (Exception e) {
            QuestingAPI.getLogger().log(Level.ERROR, "Unable to retrieve underlying JsonArray:", e);
            return null;
        }
    }

    public static void ClearCompoundTag(NBTTagCompound tag) {
        if (tag == null) {
            return;
        }
        ArrayList<String> list = new ArrayList<>(tag.func_150296_c());
        Iterator<String> it = list.iterator();
        while (it.hasNext()) {
            String key = it.next();
            tag.func_82580_o(key);
        }
    }

    public static JsonObject ReadFromFile(File file) {
        Future<JsonObject> task = BQThreadedIO.INSTANCE.enqueue(() -> {
            if (file == null || !file.exists()) {
                return new JsonObject();
            }
            try {
                FileInputStream fis = new FileInputStream(file);
                Throwable th = null;
                try {
                    InputStreamReader fr = new InputStreamReader(fis, StandardCharsets.UTF_8);
                    Throwable th2 = null;
                    try {
                        try {
                            JsonObject json = (JsonObject) GSON.fromJson(fr, JsonObject.class);
                            fr.close();
                            if (fr != null) {
                                if (0 != 0) {
                                    try {
                                        fr.close();
                                    } catch (Throwable th3) {
                                        th2.addSuppressed(th3);
                                    }
                                } else {
                                    fr.close();
                                }
                            }
                            return json;
                        } finally {
                        }
                    } catch (Throwable th4) {
                        if (fr != null) {
                            if (th2 != null) {
                                try {
                                    fr.close();
                                } catch (Throwable th5) {
                                    th2.addSuppressed(th5);
                                }
                            } else {
                                fr.close();
                            }
                        }
                        throw th4;
                    }
                } finally {
                    if (fis != null) {
                        if (0 != 0) {
                            try {
                                fis.close();
                            } catch (Throwable th6) {
                                th.addSuppressed(th6);
                            }
                        } else {
                            fis.close();
                        }
                    }
                }
            } catch (Exception e) {
                QuestingAPI.getLogger().log(Level.ERROR, "An error occured while loading JSON from file:", e);
                int i = 0;
                File file2 = new File(file.getParent(), "malformed_" + file.getName() + "0.json");
                while (true) {
                    File bkup = file2;
                    if (bkup.exists()) {
                        i++;
                        file2 = new File(file.getParent(), "malformed_" + file.getName() + i + ".json");
                    } else {
                        QuestingAPI.getLogger().log(Level.ERROR, "Creating backup at: " + bkup.getAbsolutePath());
                        CopyPaste(file, bkup);
                        return new JsonObject();
                    }
                }
            }
        });
        try {
            return task.get();
        } catch (Exception e) {
            QuestingAPI.getLogger().error("Unable to read from file " + file, e);
            return new JsonObject();
        }
    }

    public static void WriteToFile(File file, JsonObject jObj) {
        File tmp = new File(file.getAbsolutePath() + ".tmp");
        BQThreadedIO.INSTANCE.enqueue(() -> {
            FileInputStream fis;
            Throwable th;
            InputStreamReader fr;
            Throwable th2;
            try {
                if (tmp.exists()) {
                    tmp.delete();
                } else if (tmp.getParentFile() != null) {
                    tmp.getParentFile().mkdirs();
                }
                tmp.createNewFile();
                try {
                    FileOutputStream fos = new FileOutputStream(tmp);
                    Throwable th3 = null;
                    try {
                        OutputStreamWriter fw = new OutputStreamWriter(fos, StandardCharsets.UTF_8);
                        Throwable th4 = null;
                        try {
                            try {
                                GSON.toJson(jObj, fw);
                                fw.flush();
                                if (fw != null) {
                                    if (0 != 0) {
                                        try {
                                            fw.close();
                                        } catch (Throwable th5) {
                                            th4.addSuppressed(th5);
                                        }
                                    } else {
                                        fw.close();
                                    }
                                }
                                if (fos != null) {
                                    if (0 != 0) {
                                        try {
                                            fos.close();
                                        } catch (Throwable th6) {
                                            th3.addSuppressed(th6);
                                        }
                                    } else {
                                        fos.close();
                                    }
                                }
                                try {
                                    fis = new FileInputStream(tmp);
                                    th = null;
                                    try {
                                        fr = new InputStreamReader(fis, StandardCharsets.UTF_8);
                                        th2 = null;
                                    } catch (Throwable th7) {
                                        if (fis != null) {
                                            if (0 != 0) {
                                                try {
                                                    fis.close();
                                                } catch (Throwable th8) {
                                                    th.addSuppressed(th8);
                                                }
                                            } else {
                                                fis.close();
                                            }
                                        }
                                        throw th7;
                                    }
                                } catch (Exception e) {
                                    QuestingAPI.getLogger().error("An error occured while saving JSON to file (Validation check):", e);
                                    return;
                                }
                            } catch (Throwable th9) {
                                th4 = th9;
                                throw th9;
                            }
                            try {
                                try {
                                    GSON.fromJson(fr, JsonObject.class);
                                    if (fr != null) {
                                        if (0 != 0) {
                                            try {
                                                fr.close();
                                            } catch (Throwable th10) {
                                                th2.addSuppressed(th10);
                                            }
                                        } else {
                                            fr.close();
                                        }
                                    }
                                    if (fis != null) {
                                        if (0 != 0) {
                                            try {
                                                fis.close();
                                            } catch (Throwable th11) {
                                                th.addSuppressed(th11);
                                            }
                                        } else {
                                            fis.close();
                                        }
                                    }
                                    try {
                                        Files.move(tmp.toPath(), file.toPath(), StandardCopyOption.REPLACE_EXISTING);
                                    } catch (Exception e2) {
                                        QuestingAPI.getLogger().error("An error occured while saving JSON to file (Temp copy):", e2);
                                    }
                                } catch (Throwable th12) {
                                    th2 = th12;
                                    throw th12;
                                }
                            } catch (Throwable th13) {
                                if (fr != null) {
                                    if (th2 != null) {
                                        try {
                                            fr.close();
                                        } catch (Throwable th14) {
                                            th2.addSuppressed(th14);
                                        }
                                    } else {
                                        fr.close();
                                    }
                                }
                                throw th13;
                            }
                        } catch (Throwable th15) {
                            if (fw != null) {
                                if (th4 != null) {
                                    try {
                                        fw.close();
                                    } catch (Throwable th16) {
                                        th4.addSuppressed(th16);
                                    }
                                } else {
                                    fw.close();
                                }
                            }
                            throw th15;
                        }
                    } catch (Throwable th17) {
                        if (fos != null) {
                            if (0 != 0) {
                                try {
                                    fos.close();
                                } catch (Throwable th18) {
                                    th3.addSuppressed(th18);
                                }
                            } else {
                                fos.close();
                            }
                        }
                        throw th17;
                    }
                } catch (Exception e3) {
                    QuestingAPI.getLogger().error("An error occured while saving JSON to file (File write):", e3);
                }
            } catch (Exception e4) {
                QuestingAPI.getLogger().error("An error occured while saving JSON to file (Directory setup):", e4);
            }
        });
    }

    public static void CopyPaste(File fileIn, File fileOut) {
        if (fileIn.exists()) {
            try {
                if (fileOut.getParentFile() != null) {
                    fileOut.getParentFile().mkdirs();
                }
                Files.copy(fileIn.toPath(), fileOut.toPath(), StandardCopyOption.REPLACE_EXISTING);
            } catch (Exception e) {
                QuestingAPI.getLogger().log(Level.ERROR, "Failed copy paste", e);
            }
        }
    }

    public static String makeFileNameSafe(String s) {
        for (char c : ChatAllowedCharacters.field_71567_b) {
            s = s.replace(c, '_');
        }
        return s;
    }

    public static boolean isItem(NBTTagCompound json) {
        if (json != null && json.func_74764_b("id") && json.func_150297_b("Count", 99) && json.func_150297_b("Damage", 99)) {
            if (json.func_150297_b("id", 8)) {
                return Item.field_150901_e.func_148741_d(json.func_74779_i("id"));
            }
            return Item.field_150901_e.func_148754_a(json.func_74762_e("id")) != null;
        }
        return false;
    }

    public static boolean isFluid(NBTTagCompound json) {
        return json != null && json.func_150297_b("FluidName", 8) && json.func_150297_b("Amount", 99) && FluidRegistry.getFluid(json.func_74779_i("FluidName")) != null;
    }

    public static boolean isEntity(NBTTagCompound tags) {
        return tags.func_74764_b("id") && EntityList.field_75625_b.containsKey(tags.func_74779_i("id"));
    }

    @Nullable
    public static BigItemStack JsonToItemStack(@Nonnull NBTTagCompound nbt) {
        String idName = nbt.func_150297_b("id", 99) ? "" + ((int) nbt.func_74765_d("id")) : nbt.func_74779_i("id");
        Item preCheck = nbt.func_150297_b("id", 99) ? Item.func_150899_d(nbt.func_74765_d("id")) : (Item) Item.field_150901_e.func_82594_a(idName);
        if (preCheck == null && nbt.func_150297_b("id", 8)) {
            try {
                preCheck = Item.func_150899_d(Short.parseShort(idName));
            } catch (Exception e) {
            }
        }
        if (preCheck == null || preCheck == ItemPlaceholder.placeholder) {
            return PlaceholderConverter.convertItem(preCheck, idName, nbt.func_74762_e("Count"), nbt.func_74765_d("Damage"), nbt.func_74779_i("OreDict"), !nbt.func_150297_b("tag", 10) ? null : nbt.func_74775_l("tag"));
        }
        return BigItemStack.loadItemStackFromNBT(nbt);
    }

    public static NBTTagCompound ItemStackToJson(BigItemStack stack, NBTTagCompound nbt) {
        if (stack != null) {
            stack.writeToNBT(nbt);
        }
        return nbt;
    }

    public static FluidStack JsonToFluidStack(NBTTagCompound json) {
        String name = json.func_150297_b("FluidName", 8) ? json.func_74779_i("FluidName") : "water";
        int amount = json.func_74762_e("Amount");
        NBTTagCompound tags = !json.func_150297_b("Tag", 10) ? null : json.func_74775_l("Tag");
        Fluid fluid = FluidRegistry.getFluid(name);
        return PlaceholderConverter.convertFluid(fluid, name, amount, tags);
    }

    public static NBTTagCompound FluidStackToJson(FluidStack stack, NBTTagCompound json) {
        if (stack == null) {
            return json;
        }
        json.func_74778_a("FluidName", FluidRegistry.getFluidName(stack));
        json.func_74768_a("Amount", stack.amount);
        if (stack.tag != null) {
            json.func_74782_a("Tag", stack.tag);
        }
        return json;
    }

    public static Entity JsonToEntity(NBTTagCompound tags, World world) {
        Entity entity = null;
        if (tags.func_74764_b("id") && EntityList.field_75625_b.containsKey(tags.func_74779_i("id"))) {
            entity = EntityList.func_75615_a(tags, world);
        }
        return PlaceholderConverter.convertEntity(entity, world, tags);
    }

    public static NBTTagCompound EntityToJson(Entity entity, NBTTagCompound tags) {
        if (entity == null) {
            return tags;
        }
        entity.func_70039_c(tags);
        String id = EntityList.func_75621_b(entity);
        tags.func_74778_a("id", id != null ? id : "");
        return tags;
    }
}
